<!DOCTYPE html><!-- This is a valid HTML5 document. -->
<!-- Screen readers, SEO, extensions and so on. -->
<html lang="fr">
  <!-- Has to be within the first 1024 bytes, hence before the <title>
  See: https://www.w3.org/TR/2012/CR-html5-20121217/document-metadata.html#charset -->
  <meta charset="utf-8" />
  <meta name="generator" content="Crieur {{ crieur_version }}">
  <!-- Why no `X-UA-Compatible` meta: https://stackoverflow.com/a/6771584 -->
  <!-- The viewport meta is quite crowded and we are responsible for that.
  See: https://codepen.io/tigt/post/meta-viewport-for-2015 -->
  <meta name="viewport" content="width=device-width,initial-scale=1" />
  <!-- Prevent access via referrers, only the domain will be available. -->
  <meta content="origin-when-cross-origin" name="referrer" />
  <!-- Required to make a valid HTML5 document. -->
  <title>{{ title }}</title>
  <!-- Lightest blank gif, avoids an extra query to the server. -->
  <link rel="icon" href="data:;base64,iVBORw0KGgo=" />
  <link rel="stylesheet"
        href="{{ base_url }}statics/pico.css" />
  <style>
    h1 {
        text-align: center;
    }
    dt {
        font-weight: bold;
    }
  </style>
  {% block extra_head %}
  {% endblock extra_head %}

  <body>
    <main class="container">
      <div class="content">
        <h1><a href="{{ base_url }}">{{ title }}</a></h1>
        {% block content %}
        {% endblock content %}
      </div>
    </main>
    {% block extra_body %}
    {% endblock extra_body %}

  </body>
</html>
